#ifndef NT2_INCLUDE_FUNCTIONS_NONE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NONE_HPP_INCLUDED

#include <nt2/reduction/include/functions/none.hpp>

#endif
